#!/usr/bin/env python
# vim: set fileencoding=utf-8 :
"""
A JASCO data parser module

(C) 2013 hashnote.net, Alisue
"""
__author__ = 'Alisue (lambdalisue@hashnote.net)'
__version__ = '0.1.0'
import numpy as np
from graf.parser import BaseParser


class JASCOParser(BaseParser):
    """
    A JASCO parser class
    """
    def parse(self, iterable, delimiter=None, **kwargs):
        """
        Parse JASCO style iterable to an numpy array

        Args:
            iterable: an iterable instance
            delimiter: a delimiter character (Default: None).
                whitespaces include tab character is used in default
            **kwargs: optional arguments

        Returns:
            An instance of numpy array
        """
        d = []
        datamode = False
        for r in iterable:
            r = r.strip()
            c = r.split(delimiter)
            if datamode and len(r) == 0 or c[0] == '':
                break
            if datamode:
                d.append(c)
            elif c[0] == 'XYDATA':
                datamode = True
        # probably all data is numeric in JASCO txt format but I'm not sure...
        d = np.array(d, dtype=kwargs.get('dtype', float))
        return d

    def load(self, filename, delimiter=None, **kwargs):
        """
        Parse a file specified with the filename and return an numpy array

        Args:
            filename: a path of a file
            delimiter: a delimiter character (Default: None).
                whitespaces include tab character is used in default
            **kwargs: optional arguments

        Returns:
            An instance of numpy array
        """
        if filename.lower().endswith('.csv'):
            delimiter = delimiter or ','
        return super(JASCOParser, self).load(
                filename, delimiter=delimiter, **kwargs)



#!/usr/bin/env python
# coding=utf-8
"""
graf-parser-jasco

Graf plugin which allow to read JASCO (http://www.jasco.co.jp/) txt file

Usage:
    >>> 

(C) 2013 hashnote.net, Alisue
"""
name = 'graf-parser-jasco'
version = '0.1.0'
author = 'Alisue'
author_email = 'lambdalisue@hashnote.net'

import os
from setuptools import setup, find_packages

setup(
    name=name,
    version=version,
    description = "Graf parser plugin for reading JASCO txt file",
    long_description=__doc__,
    classifiers = [
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
    ],
    keywords = "graf, JASCO, parser",
    author = "Alisue",
    author_email = "lambdalisue@hashnote.net",
    license = 'MIT',
    packages = find_packages('src'),
    package_dir = {'': 'src'},
    namespace_package = [
        'graf',
        'graf.builtins',
        'graf.plugins',
        'graf.plugins.filters',
        'graf.plugins.parsers',
        'graf.plugins.loaders',
    ],
    include_package_data = True,
    exclude_package_data = {'': ['README.md']},
    zip_safe = True,
    install_requires=[
        'graf',
    ],
    entry_points={
        'graf.plugins': [
            'parsers.JASCOParser = graf.plugins.parsers.jasco:JASCOParser',
        ],
    },
)

